@@ -78,5 +78,5 @@ def command_line_runner() -> None:
     generate_histogram(hist)
 
 
-if __name__ == '__main__':
-    command_line_runner()
+# if __name__ == '__main__':
+#     command_line_runner()
